@@ -3,12 +3,9 @@
 import asyncio
 import logging
 from typing import Any
-import aiomqtt
 
-try:
-    from pydantic.v1 import ValidationError
-except ImportError:
-    from pydantic import ValidationError
+import aiomqtt
+from pydantic import ValidationError
 
 from .auth_mgr import YoLinkAuthMgr
 from .device import YoLinkDevice
@@ -58,7 +55,7 @@ class YoLinkMqttClient:
                     port=self._broker_port,
                     username=self._auth_mgr.access_token(),
                     password="",
-                    keepalive=50,
+                    keepalive=60,
                 ) as client:
                     _LOGGER.info(
                         "[%s] connecting to yolink mqtt broker.", self._endpoint
@@ -116,6 +113,7 @@ class YoLinkMqttClient:
                     "getState",
                     "setState",
                     "DevEvent",
+                    "waterReport",  # Sprinkler
                 ]:
                     return
                 device = self._home_devices.get(device_id)
